PCB Environment: Camera Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
Camera Class Reference

`#include <Camera.hpp>`

## Public Member Functions
QPointF | worldPosToNormalizedPos (const Point_2 &) const
| normalizedPos is 0 to 1 within the GL widget (= camera view area)
Point_2 | normalizedPosToWorldPos (const QPointF &) const
bool | isVisible (const Bbox_2 &bbox) const
void | loadUniforms ()
float | adjustLineWidth (float) const
void | setBaseDimensions (uint w, uint h, double unitsPerNanoMeter)
void | setZoom (float, QPointF anchor=QPointF(0.5, 0.5))
void | setOrigin (const Point_2 &)
void | setOriginRelative (const Vector_2 &)
void | setCenter (const Point_2 &)
void | setView (const Point_2 &origin, const Vector_2 &size)
void | setZNear (float z)
void | setZFar (float z)
void | setZRange (float near, float far)
void | moveBy (const Vector_2 &v)
const Bbox_2 | getBbox () const
const float | getZoom () const
const Vector_2 & | getDims () const
const Point_2 & | getCornerMin () const
const Point_2 & | getCornerMax () const
const Point_2 & | getOrigin () const
const math::Mat4 & | getMVP () const
const float * | getFloatMVP () const
GLuint | getUBO () const

## Data Fields
struct { |
GLfloat MVP [16] |
} | mUniforms

## Detailed Description

Camera CLASS Controls the view of the board. Zoom: multiplier for view area, i.e. smaller values zoom in

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/Camera.hpp